/*
** Module   : ChuiAppletHandler.java
** Abstract : customizes the applet configuration for the CHUI simulator applet 
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**         Golden Code Development Corporation
**                 CONFIDENTIAL
**
** -#- -I- --Date-- ----------------------Description--------------------------
** 001 GES 20111004 First version.
** 002 MAG 20131101 Upgrade to jetty 9.1 embedded server 
*/

package com.goldencode.p2j.main;
                                                 
import org.eclipse.jetty.server.*;

import com.goldencode.p2j.ui.client.chui.driver.swing.*;
import com.goldencode.p2j.util.*;
                                              
/**
 * Customizes the applet configuration for the CHUI simulator applet.
 */
public class ChuiAppletHandler
extends AppletHandler
{
   /** Path to the skeleton applet HTML file. */
   private static final String CHUI_SKEL = "/com/goldencode/p2j/ui/client/" +
                                           "chui/driver/swing/chui_applet.html";
   
   /** Number of terminal rows. */
   private String rows;
   
   /** Number of terminal columns. */
   private String columns;
   
   /** Background color. */
   private String background =
      Integer.toHexString(TerminalOptions.DEF_BACKGROUND.getRGB());
   
   /** Foreground color. */
   private String foreground =
      Integer.toHexString(TerminalOptions.DEF_FOREGROUND.getRGB());
   
   /** Selection color. */
   private String selection =
      Integer.toHexString(TerminalOptions.DEF_SELECTION.getRGB());
   
   /** Font family name. */
   private String fontname = TerminalOptions.DEF_FONTNAME;
   
   /** Font size. */
   private String fontsize;
   
   /**
    * Constructor.
    */
   public ChuiAppletHandler()
   {
      super("chui", CHUI_SKEL, null);
      
      int r = Utils.getDirectoryNodeInt(null,
                                        "chuiApplet/rows", 
                                        TerminalOptions.DEF_ROWS, 
                                        false);
      rows = Integer.toString(r);
      
      int c = Utils.getDirectoryNodeInt(null,
                                        "chuiApplet/columns", 
                                        TerminalOptions.DEF_COLUMNS, 
                                        false);
      columns = Integer.toString(c);
      
      background = Utils.getDirectoryNodeString(null,
                                                "chuiApplet/background", 
                                                background, 
                                                false);
      
      foreground = Utils.getDirectoryNodeString(null,
                                                "chuiApplet/foreground", 
                                                foreground, 
                                                false);
      
      selection = Utils.getDirectoryNodeString(null,
                                               "chuiApplet/selection", 
                                               background, 
                                               false);
      
      fontname = Utils.getDirectoryNodeString(null,
                                              "chuiApplet/fontname", 
                                              fontname, 
                                              false);
      
      int f = Utils.getDirectoryNodeInt(null,
                                        "chuiApplet/fontsize", 
                                        TerminalOptions.DEF_FONTSIZE, 
                                        false);
      fontsize = Integer.toString(f);
   }
   
   /**
    * Process the given string and make any replacements of parameter values
    * as needed.  Generally, the format of the replacement placeholder is
    * a % character followed by a placeholder name, but this is just a
    * convention.
    * <p>
    * This code customizes the following CHUI terminal settings based on
    * defaults or optionally read from the directory:
    * <p>
    * <pre>
    * Name               Default       Type                                                          Directory Node ID
    * -----------------  ------------  ------------------------------------------------------------  -------------------
    * %chui_rows         24            integer (number of rows on the "terminal")                    chuiApplet/rows
    * %chui_columns      80            integer (number of columns on the "terminal")                 chuiApplet/columns
    * %chui_background   0x000000      text which can be converted to a Color by Color.decode()      chuiApplet/background
    * %chui_foreground   0xFFA500      text which can be converted to a Color by Color.decode()      chuiApplet/foreground
    * %chui_selection    0x00FF00      text which can be converted to a Color by Color.decode()      chuiApplet/selection
    * %chui_fontname     monospaced    text containing a monospaced (fixed width) font family name   chuiApplet/fontname
    * %chui_fontsize     12            integer                                                       chuiApplet/fontsize
    * </pre>
    *
    * @param    base
    *           The details and state the request.
    * @param    text
    *           The text line that may need modifications.
    *
    * @return   The new text if a modification occurred or the original text
    *           if no modification was needed.
    */
   protected String handleReplacements(Request base, String text)
   {
      // let our parent go first
      text = super.handleReplacements(base, text);
      
      if (text.contains("%chui_rows"))
      {
         text = text.replace("%chui_rows", rows);
      }
      else if (text.contains("%chui_columns"))
      {
         text = text.replace("%chui_columns", columns);
      }
      else if (text.contains("%chui_background"))
      {
         text = text.replace("%chui_background", background);
      }
      else if (text.contains("%chui_foreground"))
      {
         text = text.replace("%chui_foreground", foreground);
      }
      else if (text.contains("%chui_selection"))
      {
         text = text.replace("%chui_selection", selection);
      }
      else if (text.contains("%chui_fontname"))
      {
         text = text.replace("%chui_fontname", fontname);
      }
      else if (text.contains("%chui_fontsize"))
      {
         text = text.replace("%chui_fontsize", fontsize);
      }
      
      return text;
   }
}
